@@ -46,7 +46,6 @@ from scipy.optimize import curve_fit
 from six.moves import cStringIO as StringIO
 from tabulate import tabulate
 
-import boost.python
 import iotbx.phil
 from cctbx import miller
 from libtbx.phil import scope, scope_extract
@@ -56,15 +55,13 @@ from dials.util import log
 from dials.util.options import OptionParser
 from dials.util.version import dials_version
 from dxtbx.model import Experiment, ExperimentList
+
 from screen19 import __version__, d_ticks, plot_intensities, terminal_size
 
 # Custom types
 FloatSequence = Sequence[float]
 Fit = Union[np.ndarray, Iterable, int, float]
 
-# Suppress unhelpful matplotlib crash due to boost.python's overzealous allergy to FPEs
-boost.python.floating_point_exceptions.division_by_zero_trapped = False
-
 help_message = __doc__
 
 
@@ -248,7 +245,14 @@ def wilson_plot_image(
     plt.ylabel(u"Intensity (counts)")
     if ticks:
         plt.xticks([1 / d ** 2 for d in ticks], ["%g" % d for d in ticks])
-    plt.yscale("log", nonposy="clip")
+
+    # Matplotlib v3.3.0 includes API change 'nonposy' → 'nonpositive'
+    # https://matplotlib.org/api/api_changes.html#log-symlog-scale-base-ticks-and-nonpos-specification
+    try:
+        plt.yscale("log", nonpositive="clip")
+    except ValueError:
+        plt.yscale("log", nonposy="clip")
+
     plt.plot(d_star_sq, intensity, "b.", label=None)
     plt.plot(
         d_star_sq, scaled_debye_waller(d_star_sq, *fit), "r-", label="Debye-Waller fit"
