@@ -65,7 +65,6 @@ from libtbx.phil import scope
 
 import dials.command_line.integrate
 import dials.util.version
-import screen19
 from dials.algorithms.indexing import DialsIndexError
 from dials.algorithms.indexing.bravais_settings import (
     refined_settings_from_refined_triclinic,
@@ -91,6 +90,8 @@ from dxtbx.model.experiment_list import (
     ExperimentListTemplateImporter,
     GoniometerComparison,
 )
+
+import screen19
 from screen19.minimum_exposure import suggest_minimum_exposure
 
 Templates = List[Tuple[str, Tuple[int, int]]]
@@ -265,7 +266,14 @@ def overloads_histogram(d_spacings, ticks=None, output="overloads"):
     plt.ylabel(u"Number of overloaded reflections")
     if ticks:
         plt.xticks([1 / d for d in ticks], ["%g" % d for d in ticks])
-    plt.yscale("log", nonposy="clip")
+
+    # Matplotlib v3.3.0 includes API change 'nonposy' → 'nonpositive'
+    # https://matplotlib.org/api/api_changes.html#log-symlog-scale-base-ticks-and-nonpos-specification
+    try:
+        plt.yscale("log", nonpositive="clip")
+    except ValueError:
+        plt.yscale("log", nonposy="clip")
+
     plt.hist(d_spacings, min(100, d_spacings.size()))
     plt.savefig(output)
     plt.close()
@@ -581,7 +589,7 @@ class Screen19(object):
         command = ["xia2.overload", "nproc=%s" % self.nproc, "indexed.expt"]
         debug("running %s", command)
         result = procrunner.run(command, print_stdout=False, debug=procrunner_debug)
-        debug("result = %s", screen19.prettyprint_dictionary(result))
+        debug("result = %s", screen19.prettyprint_procrunner(result))
         info("Successfully completed (%.1f sec)", result["runtime"])
 
         if result["exitcode"] != 0:
@@ -877,7 +885,7 @@ class Screen19(object):
             "output = %s" % self.params.dials_index.output.experiments,
         ]
         result = procrunner.run(command, print_stdout=False, debug=procrunner_debug)
-        debug("result = %s", screen19.prettyprint_dictionary(result))
+        debug("result = %s", screen19.prettyprint_procrunner(result))
         self._sigma_m = None
         if result["exitcode"] == 0:
             db = ExperimentList.from_file(self.params.dials_index.output.experiments)[0]
@@ -945,7 +953,7 @@ class Screen19(object):
             info("\nRefining Bravais settings...")
             command = ["dials.refine_bravais_settings", experiments, reflections]
             result = procrunner.run(command, print_stdout=False, debug=procrunner_debug)
-            debug("result = %s", screen19.prettyprint_dictionary(result))
+            debug("result = %s", screen19.prettyprint_procrunner(result))
             if result["exitcode"] == 0:
                 m = re.search(
                     r"[-+]{3,}\n[^\n]*\n[-+|]{3,}\n(.*\n)*[-+]{3,}",
@@ -1009,7 +1017,7 @@ class Screen19(object):
         info("\nCreating report...")
         command = ["dials.report", experiments, reflections]
         result = procrunner.run(command, print_stdout=False, debug=procrunner_debug)
-        debug("result = %s", screen19.prettyprint_dictionary(result))
+        debug("result = %s", screen19.prettyprint_procrunner(result))
         if result["exitcode"] == 0:
             info("Successfully completed (%.1f sec)", result["runtime"])
         #     if sys.stdout.isatty():
